@@ -1,5 +1,4 @@
-# -*- coding: utf-8 -*-
-# Copyright (C) 2010-2012 Bastian Kleineidam
+# Copyright (C) 2010-2023 Bastian Kleineidam
 #
 # This program is free software: you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
@@ -13,15 +12,19 @@
 #
 # You should have received a copy of the GNU General Public License
 # along with this program.  If not, see <http://www.gnu.org/licenses/>.
+"""Test the lcab program"""
+
 from . import ArchiveTest
 from .. import needs_program
 
-class TestLcab (ArchiveTest):
+
+class TestLcab(ArchiveTest):
+    """Test class for the lcab program"""
 
     program = 'lcab'
 
     @needs_program(program)
     @needs_program('cabextract')
-    def test_lcab (self):
+    def test_lcab(self):
+        """Create a CAB archive."""
         self.archive_create('t.cab')
-
