@@ -1,5 +1,4 @@
-# -*- coding: utf-8 -*-
-# Copyright (C) 2010-2015 Bastian Kleineidam
+# Copyright (C) 2010-2023 Bastian Kleineidam
 #
 # This program is free software: you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
@@ -13,15 +12,20 @@
 #
 # You should have received a copy of the GNU General Public License
 # along with this program.  If not, see <http://www.gnu.org/licenses/>.
+"""Test the mac program"""
+
 from . import ArchiveTest
 from .. import needs_program
 
-class TestMac (ArchiveTest):
+
+class TestMac(ArchiveTest):
+    """Test class for the mac program"""
 
     program = 'mac'
 
     @needs_program(program)
     def test_mac(self):
+        """Extract, test and create an APE archive."""
         self.archive_extract('t.ape', check=None)
         self.archive_test('t.ape')
         self.archive_create('t.ape', srcfiles=("t.wav",))
@@ -29,5 +33,5 @@ class TestMac (ArchiveTest):
     @needs_program('file')
     @needs_program(program)
     def test_mac_file(self):
+        """Extract a renamed APE archive."""
         self.archive_extract('t.ape.foo', check=None)
-
