@@ -1,5 +1,4 @@
-# -*- coding: utf-8 -*-
-# Copyright (C) 2010-2016 Bastian Kleineidam
+# Copyright (C) 2010-2023 Bastian Kleineidam
 #
 # This program is free software: you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
@@ -13,23 +12,31 @@
 #
 # You should have received a copy of the GNU General Public License
 # along with this program.  If not, see <http://www.gnu.org/licenses/>.
+"""Test the python zipfile module"""
+
 from . import ArchiveTest
 from .. import needs_program
 
-class TestPyzipfile (ArchiveTest):
+
+class TestPyzipfile(ArchiveTest):
+    """Test class for the python zipfile module"""
 
     program = 'py_zipfile'
 
     def test_py_zipfile(self):
+        """Run archive commands with ZIP and CBZ archive."""
         self.archive_commands(self.filename + '.zip')
         self.archive_commands(self.filename + '.cbz')
 
     @needs_program('file')
     def test_py_zipfile_file(self):
+        """Run archive commands with renamed ZIP and CBZ archive."""
         self.archive_commands(self.filename + '.zip.foo', skip_create=True)
         self.archive_commands(self.filename + '.cbz.foo', skip_create=True)
 
-class TestPyzipPasswordfile (TestPyzipfile):
+
+class TestPyzipPasswordfile(TestPyzipfile):
+    """Test class for the python zipfile module with password protection"""
 
     filename = 'p'
     password = 'thereisnotry'
