@@ -1,5 +1,4 @@
-# -*- coding: utf-8 -*-
-# Copyright (C) 2010-2012 Bastian Kleineidam
+# Copyright (C) 2010-2023 Bastian Kleineidam
 #
 # This program is free software: you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
@@ -13,13 +12,18 @@
 #
 # You should have received a copy of the GNU General Public License
 # along with this program.  If not, see <http://www.gnu.org/licenses/>.
+"""Test the unshar program"""
+
 from . import ArchiveTest
 from .. import needs_program
 
-class TestUnshar (ArchiveTest):
+
+class TestUnshar(ArchiveTest):
+    """Test class for the unshar program"""
 
     program = 'unshar'
 
     @needs_program(program)
     def test_unshar(self):
+        """Extract a SHAR archive."""
         self.archive_extract('t.shar', check=None)
